@@ -8,6 +8,6 @@ pub enum Delimiter {
 impl Delimiter {
     #[inline]
     pub fn into_node(self, range: Option<OffsetRange>) -> ASTNode {
-        ASTNode { value: ASTKind::Delimiter(Box::new(self)), range }
+        ASTNode { value: ASTKind::Delimiter(box self), range }
     }
 }
